@@ -16,4 +16,5 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from .nfft import NFFT, Solver
+from pynfft.nfft import NFFT
+from pynfft.solver import Solver
